@@ -63,31 +63,31 @@ private Q_SLOTS:
         QCOMPARE(array.size(), 1);
         auto obj = array.at(0).toObject();
         QCOMPARE(obj.value(QLatin1StringView("@context")).toString(),
-                 QLatin1String("http://schema.org"));
+                 QLatin1StringView("http://schema.org"));
         QCOMPARE(obj.value(QLatin1StringView("@type")).toString(),
-                 QLatin1String("Flight"));
+                 QLatin1StringView("Flight"));
         QCOMPARE(obj.value(QLatin1StringView("flightNumber")).toString(),
-                 QLatin1String("1234"));
+                 QLatin1StringView("1234"));
 
         QCOMPARE(obj.value(QLatin1StringView("arrivalTime")).toString(),
-                 QLatin1String("2018-03-18T19:44:00Z"));
+                 QLatin1StringView("2018-03-18T19:44:00Z"));
         auto dtObj = obj.value(QLatin1StringView("departureTime")).toObject();
         QCOMPARE(dtObj.value(QLatin1StringView("@value")).toString(),
-                 QLatin1String("2018-03-18T18:44:00+01:00"));
+                 QLatin1StringView("2018-03-18T18:44:00+01:00"));
         QCOMPARE(dtObj.value(QLatin1StringView("@type")).toString(),
-                 QLatin1String("QDateTime"));
+                 QLatin1StringView("QDateTime"));
         QCOMPARE(dtObj.value(QLatin1StringView("timezone")).toString(),
-                 QLatin1String("Europe/Berlin"));
+                 QLatin1StringView("Europe/Berlin"));
         QCOMPARE(obj.value(QLatin1StringView("departureDay")).toString(),
-                 QLatin1String("2018-03-18"));
+                 QLatin1StringView("2018-03-18"));
 
         auto obj2 = obj.value(QLatin1StringView("departureAirport")).toObject();
         QCOMPARE(obj2.value(QLatin1StringView("@type")).toString(),
-                 QLatin1String("Airport"));
+                 QLatin1StringView("Airport"));
 
         QVERIFY(obj.contains(QLatin1StringView("departureGate")));
         QCOMPARE(obj.value(QLatin1StringView("departureGate")).toString(),
-                 QLatin1String(""));
+                 QLatin1StringView(""));
 
         QVERIFY(obj.contains(QLatin1StringView("airline")));
 
@@ -113,16 +113,16 @@ private Q_SLOTS:
                  reservationNumber);
         auto resDtObj = obj.value(QLatin1StringView("startTime")).toObject();
         QCOMPARE(resDtObj.value(QLatin1StringView("@value")).toString(),
-                 QLatin1String("2018-03-18T18:44:00+01:00"));
+                 QLatin1StringView("2018-03-18T18:44:00+01:00"));
         QCOMPARE(resDtObj.value(QLatin1StringView("@type")).toString(),
-                 QLatin1String("QDateTime"));
+                 QLatin1StringView("QDateTime"));
         QCOMPARE(resDtObj.value(QLatin1StringView("timezone")).toString(),
-                 QLatin1String("Europe/Berlin"));
+                 QLatin1StringView("Europe/Berlin"));
         qDebug().noquote() << QJsonDocument(obj).toJson();
         auto undernameObj =
             obj.value(QLatin1StringView("underName")).toObject();
         QCOMPARE(undernameObj.value(QLatin1StringView("name")).toString(),
-                 QLatin1String("John"));
+                 QLatin1StringView("John"));
 
         //Rental Car
         RentalCarReservation rentalRes;
@@ -166,20 +166,20 @@ private Q_SLOTS:
         auto pickupTimeObj =
             obj.value(QLatin1StringView("dropoffTime")).toObject();
         QCOMPARE(pickupTimeObj.value(QLatin1StringView("@value")).toString(),
-                 QLatin1String("2018-03-21T18:44:00+01:00"));
+                 QLatin1StringView("2018-03-21T18:44:00+01:00"));
         QCOMPARE(pickupTimeObj.value(QLatin1StringView("@type")).toString(),
-                 QLatin1String("QDateTime"));
+                 QLatin1StringView("QDateTime"));
         QCOMPARE(pickupTimeObj.value(QLatin1StringView("timezone")).toString(),
-                 QLatin1String("Europe/Berlin"));
+                 QLatin1StringView("Europe/Berlin"));
 
         auto droptimeObj =
             obj.value(QLatin1StringView("pickupTime")).toObject();
         QCOMPARE(droptimeObj.value(QLatin1StringView("@value")).toString(),
-                 QLatin1String("2018-03-18T18:44:00+01:00"));
+                 QLatin1StringView("2018-03-18T18:44:00+01:00"));
         QCOMPARE(droptimeObj.value(QLatin1StringView("@type")).toString(),
-                 QLatin1String("QDateTime"));
+                 QLatin1StringView("QDateTime"));
         QCOMPARE(droptimeObj.value(QLatin1StringView("timezone")).toString(),
-                 QLatin1String("Europe/Berlin"));
+                 QLatin1StringView("Europe/Berlin"));
     }
 
     void testDeserialization()
