@@ -43,6 +43,7 @@
 #include <QDebug>
 #include <QJsonArray>
 #include <QJsonDocument>
+#include <QMetaProperty>
 #include <QTimeZone>
 #include <QUrl>
 
@@ -51,6 +52,7 @@
 #endif
 
 #include <algorithm>
+#include <cmath>
 #include <cstring>
 
 using namespace Qt::Literals::StringLiterals;
@@ -113,11 +115,19 @@ void ExtractorPostprocessor::process(const QList<QVariant> &data) {
     }
 }
 
-[[nodiscard]] static QVariant mergeTicket(QVariant lhs, const QVariant &rhs)
+[[nodiscard]] static QVariant mergeBaseReservation(QVariant lhs, const QVariant &rhs)
 {
-    const auto rhsTicket = JsonLdDocument::readProperty(rhs, "reservedTicket");
-    const auto lhsTicket = JsonLdDocument::readProperty(lhs, "reservedTicket");
-    JsonLdDocument::writeProperty(lhs, "reservedTicket", MergeUtil::merge(lhsTicket, rhsTicket));
+    for (auto i = 0; i < Reservation::staticMetaObject.propertyCount(); ++i) {
+        const auto prop = Reservation::staticMetaObject.property(i);
+        if (!prop.isWritable() || !prop.isStored() || std::strcmp(prop.name(), "reservationFor") == 0) {
+            continue;
+        }
+        const auto lhsVal = JsonLdDocument::readProperty(lhs, prop.name());
+        const auto rhsVal = JsonLdDocument::readProperty(rhs, prop.name());
+        if (!JsonLd::valueIsNull(rhsVal)) {
+            JsonLdDocument::writeProperty(lhs, prop.name(), JsonLd::valueIsNull(lhsVal) ? rhsVal : MergeUtil::merge(rhsVal, lhsVal));
+        }
+    }
     return lhs;
 }
 
@@ -166,8 +176,8 @@ QList<QVariant> ExtractorPostprocessor::result() const {
                 }
 
                 if (depIt != it && arrIt != it && depIt != arrIt) {
-                    (*depIt) = mergeTicket(*depIt, *it);
-                    (*arrIt) = mergeTicket(*arrIt, *it);
+                    (*depIt) = mergeBaseReservation(*depIt, *it);
+                    (*arrIt) = mergeBaseReservation(*arrIt, *it);
                     it = d->m_data.erase(it);
                 } else {
                     ++it;
@@ -531,7 +541,26 @@ T ExtractorPostprocessorPrivate::processReservation(T res) const
     res.setPriceCurrency(processCurrency(res.priceCurrency()));
 
     if (JsonLd::isA<Ticket>(res.reservedTicket())) {
-        res.setReservedTicket(processTicket(res.reservedTicket().template value<Ticket>()));
+        // move information that can exist in Ticket and Reservation up to the latter
+        auto ticket = processTicket(res.reservedTicket().template value<Ticket>());
+        if (res.underName().isNull() && !ticket.name().isEmpty()) {
+            res.setUnderName(ticket.underName());
+            ticket.setUnderName({});
+        } else if (ticket.underName() == res.underName().template value<Person>()) {
+            ticket.setUnderName({});
+        }
+
+        if ((!res.priceCurrency().isEmpty() && res.priceCurrency() == ticket.priceCurrency())
+            && (!std::isnan(res.totalPrice()) && res.totalPrice() == ticket.totalPrice())) {
+            ticket.setPriceCurrency({});
+            ticket.setTotalPrice(NAN);
+        }
+
+        if (ticket.ticketNumber() == res.reservationNumber()) {
+            ticket.setTicketNumber({});
+        }
+
+        res.setReservedTicket(processTicket(ticket));
     }
     return res;
 }
