@@ -16,12 +16,6 @@ struct UicCountryCodeMapping {
     CountryId isoCode;
 };
 
-/** ISO 3166-1 alpha 3 to ISO 3166-1 alpha 2 mapping. */
-struct IsoCountryCodeMapping {
-    CountryId3 iso3Code;
-    CountryId  iso2Code;
-};
-
 }
 }
 
