@@ -52,6 +52,7 @@ static bool operator<(const CompareFunc &lhs, int rhs)
 static std::vector<CompareFunc> s_mergeCompareFuncs;
 }
 
+using namespace Qt::Literals;
 using namespace KItinerary;
 
 /* Compare times without assuming times without a timezone are in the current time zone
@@ -120,6 +121,7 @@ static bool isSameEvent(const Event &lhs, const Event &rhs);
 static bool isSameRentalCar(const RentalCar &lhs, const RentalCar &rhs);
 static bool isSameTaxiTrip(const Taxi &lhs, const Taxi &rhs);
 static bool isSameReservation(const Reservation &lhsRes, const Reservation &rhsRes);
+static bool isSameSeat(const Seat &lhsSeat, const Seat &rhsSeat);
 static bool isMinimalCancelationFor(const Reservation &res, const Reservation &cancel);
 
 bool isSameReservation(const Reservation &lhsRes, const Reservation &rhsRes)
@@ -132,13 +134,41 @@ bool isSameReservation(const Reservation &lhsRes, const Reservation &rhsRes)
 
     const auto lhsTicket = lhsRes.reservedTicket().value<Ticket>();
     const auto rhsTicket = rhsRes.reservedTicket().value<Ticket>();
-    if (conflictIfPresent(lhsTicket.ticketedSeat().seatNumber(), rhsTicket.ticketedSeat().seatNumber(), Qt::CaseInsensitive)) {
+    if (!isSameSeat(lhsTicket.ticketedSeat(), rhsTicket.ticketedSeat())) {
         return false;
     }
 
     return true;
 }
 
+bool isSameSeat(const Seat &lhsSeat, const Seat &rhsSeat)
+{
+    // check for coach number conflicts
+    if (!lhsSeat.seatSection().isEmpty() && !rhsSeat.seatSection().isEmpty()) {
+        bool lhsOk = false, rhsOk = false;
+        const auto lhsNum = lhsSeat.seatSection().toInt(&lhsOk);
+        const auto rhsNum = rhsSeat.seatSection().toInt(&rhsOk);
+        if (lhsOk && rhsOk && lhsNum > 0 && rhsNum > 0 && lhsNum != rhsNum) {
+            return false;
+        }
+        if ((!lhsOk || !rhsOk) && lhsSeat.seatSection().compare(rhsSeat.seatSection(), Qt::CaseInsensitive) != 0) {
+            return false;
+        }
+    }
+
+    // check for seat number conflicts
+    if (conflictIfPresent(lhsSeat.seatNumber(), rhsSeat.seatNumber(), Qt::CaseInsensitive)) {
+        const QRegularExpression rx(uR"([[:space:][:punct:]])"_s);
+        auto lhsSet = lhsSeat.seatNumber().toCaseFolded().split(rx, Qt::SkipEmptyParts);
+        auto rhsSet = rhsSeat.seatNumber().toCaseFolded().split(rx, Qt::SkipEmptyParts);
+        std::ranges::sort(lhsSet);
+        std::ranges::sort(rhsSet);
+        return lhsSet == rhsSet;
+    }
+
+    return true;
+}
+
 bool isSubType(const QVariant &lhs, const QVariant &rhs)
 {
     const auto lhsMt = QMetaType(lhs.userType());
@@ -439,12 +469,40 @@ static bool isSameLineName(const Iter &lBegin, const Iter &lEnd, const Iter &rBe
     return (lIt != lEnd && (*lIt).isSpace()) || (rIt != rEnd && (*rIt).isSpace());
 }
 
+struct {
+    const char *match;
+    const char *replace;
+} static constexpr const train_normalization_patterns[] = {
+    { "intercityexpress", "ice" },
+    { "intercity", "ic" },
+};
+
+static QString normalizeTrainName(QStringView name)
+{
+    QString normalized;
+    normalized.reserve(name.size());
+    for (const auto c : name) {
+        if (!c.isDigit() && !c.isLetter()) {
+            continue;
+        }
+        normalized.push_back(c.toCaseFolded());
+    }
+
+    for (const auto &pattern : train_normalization_patterns) {
+        normalized.replace(QLatin1StringView(pattern.match), QLatin1StringView(pattern.replace));
+    }
+
+    return normalized;
+}
+
 static bool isSameTrainName(QStringView lhs, QStringView rhs)
 {
     if (lhs.isEmpty() || rhs.isEmpty()) {
         return false;
     }
-    return lhs.startsWith(rhs) || rhs.startsWith(lhs);
+    const auto normalizedLhs = normalizeTrainName(lhs);
+    const auto normalizedRhs = normalizeTrainName(rhs);
+    return normalizedLhs.startsWith(normalizedRhs) || normalizedRhs.startsWith(normalizedLhs);
 }
 
 static bool isSameLineName(const QString &lhs, const QString &rhs)
@@ -456,7 +514,7 @@ static bool isSameLineName(const QString &lhs, const QString &rhs)
     }
 
     // deal with both line and route numbers being specified
-    static QRegularExpression rx(QStringLiteral(R"(^(?<type>[A-Za-z]+) (?<line>\d+)(?: \((?<route>\d{4,})\))?$)"));
+    static QRegularExpression rx(QStringLiteral(R"(^(?<type>[A-Za-z-]+) (?<line>\d+)(?: \((?<route>\d{4,})\))?$)"));
     const auto lhsMatch = rx.match(lhs);
     const auto rhsMatch = rx.match(rhs);
     if (!lhsMatch.hasMatch() || !rhsMatch.hasMatch()) {
@@ -475,13 +533,7 @@ static bool isSameTrainTrip(const TrainTrip &lhs, const TrainTrip &rhs)
         return false;
     }
 
-    // for unbound tickets, comparing the line number below won't help
-    // so we have to use the slightly less robust location comparison
-    if (!lhs.departureTime().isValid() && !rhs.departureTime().isValid()) {
-        qCDebug(CompareLog) << "unbound trip" << lhs.departureStation().name() << rhs.departureStation().name() << lhs.arrivalStation().name() << rhs.arrivalStation().name();
-        return LocationUtil::isSameLocation(lhs.departureStation(), rhs.departureStation(), LocationUtil::Exact)
-            && LocationUtil::isSameLocation(lhs.arrivalStation(), rhs.arrivalStation(), LocationUtil::Exact);
-    } else if (lhs.departureTime().isValid() && rhs.departureTime().isValid()) {
+    if (lhs.departureTime().isValid() && rhs.departureTime().isValid()) {
         // if we have both departure times, they have to match
         qCDebug(CompareLog) << "departure time" << lhs.departureTime() << rhs.departureTime() <<equalAndPresent(lhs.departureTime(), rhs.departureTime());
         if (!equalAndPresent(lhs.departureTime(), rhs.departureTime())) {
@@ -507,11 +559,21 @@ static bool isSameTrainTrip(const TrainTrip &lhs, const TrainTrip &rhs)
         }
     }
 
-    // if we don't have train numbers, also fall back to the less robust location comparison
+    // if we don't have train numbers, fall back to the less robust location comparison
+    // we want at least one side to be an exact match to be reaonsbaly sure
     if (lhs.trainNumber().isEmpty() || rhs.trainNumber().isEmpty()) {
         qCDebug(CompareLog) << "missing train number" << lhs.trainNumber() << rhs.trainNumber();
-        return LocationUtil::isSameLocation(lhs.departureStation(), rhs.departureStation(), LocationUtil::Exact)
-            && LocationUtil::isSameLocation(lhs.arrivalStation(), rhs.arrivalStation(), LocationUtil::Exact);
+        const auto depExact = LocationUtil::isSameLocation(lhs.departureStation(), rhs.departureStation(), LocationUtil::Exact);
+        const auto arrExact = LocationUtil::isSameLocation(lhs.arrivalStation(), rhs.arrivalStation(), LocationUtil::Exact);
+        if (depExact && arrExact) {
+            return true;
+        }
+        if (!depExact && !arrExact) {
+            return false;
+        }
+         return LocationUtil::isSameLocation(lhs.departureStation(), rhs.departureStation(), LocationUtil::CityLevel)
+             || LocationUtil::isSameLocation(lhs.arrivalStation(), rhs.arrivalStation(), LocationUtil::CityLevel);
+
     }
 
     const auto isSameLine = isSameLineName(lhs.trainNumber(), rhs.trainNumber());
@@ -769,7 +831,7 @@ QVariant MergeUtil::merge(const QVariant &lhs, const QVariant &rhs)
     if (lhs.isNull()) {
         return rhs;
     }
-    if (!isSubType(lhs, rhs) && !isSubType(rhs, lhs)) {
+    if (lhs.typeId() != rhs.typeId() && !isSubType(lhs, rhs) && !isSubType(rhs, lhs)) {
         qCWarning(Log) << "type mismatch during merging:" << lhs << rhs;
         return {};
     }
@@ -783,41 +845,54 @@ QVariant MergeUtil::merge(const QVariant &lhs, const QVariant &rhs)
         }
     }
 
+    // handle simple value types
+    if (lhs.typeId() == rhs.typeId()) {
+        const auto mt = lhs.typeId();
+        if (mt == qMetaTypeId<Airline>()) {
+            return mergeValue(lhs.value<Airline>(), rhs.value<Airline>());
+        }
+        if (mt == qMetaTypeId<Person>()) {
+            return mergeValue(lhs.value<Person>(), rhs.value<Person>());
+        }
+        if (mt == QMetaType::QDateTime) {
+            return mergeValue(lhs.toDateTime(), rhs.toDateTime());
+        }
+        if (mt == qMetaTypeId<Ticket>()) {
+            return mergeValue(lhs.value<Ticket>(), rhs.value<Ticket>());
+        }
+        if (mt == QMetaType::QString) {
+            return StringUtil::betterString(lhs.toString(), rhs.toString()).toString();
+        }
+        if ((QMetaType(mt).flags() & QMetaType::IsGadget) == 0 && !JsonLd::valueIsNull(rhs)) {
+            return rhs;
+        }
+    }
+
     auto res = lhs;
     if (lhs.userType() != rhs.userType() && isSubType(rhs, lhs)) {
         res = rhs;
     }
 
-    const auto mo = QMetaType(res.userType()).metaObject();
-    for (int i = 0; i < mo->propertyCount(); ++i) {
-        const auto prop = mo->property(i);
-        if (!prop.isStored()) {
-            continue;
-        }
+    const auto mt = QMetaType(res.typeId());
+    const auto mo = QMetaType(res.typeId()).metaObject();
+    if (mo && (mt.flags() & QMetaType::IsGadget)) {
+        for (int i = 0; i < mo->propertyCount(); ++i) {
+            const auto prop = mo->property(i);
+            if (!prop.isStored()) {
+                continue;
+            }
 
-        auto lv = prop.readOnGadget(lhs.constData());
-        auto rv = prop.readOnGadget(rhs.constData());
-        auto mt = rv.userType();
-        const auto metaType = QMetaType(mt);
+            const auto lv = prop.readOnGadget(lhs.constData());
+            auto rv = prop.readOnGadget(rhs.constData());
+            if (rv.typeId() == QMetaType::QVariantList && std::strcmp(prop.name(), "subjectOf") == 0) {
+                rv = mergeSubjectOf(lv.toList(), rv.toList());
+            } else {
+                rv = MergeUtil::merge(lv, rv);
+            }
 
-        if (mt == qMetaTypeId<Airline>()) {
-            rv = mergeValue(lv.value<Airline>(), rv.value<Airline>());
-        } else if (mt == qMetaTypeId<Person>()) {
-            rv = mergeValue(lv.value<Person>(), rv.value<Person>());
-        } else if (mt == QMetaType::QDateTime) {
-            rv = mergeValue(lv.toDateTime(), rv.toDateTime());
-        } else if (mt == qMetaTypeId<Ticket>()) {
-            rv = mergeValue(lv.value<Ticket>(), rv.value<Ticket>());
-        } else if ((metaType.flags() & QMetaType::IsGadget) && metaType.metaObject()) {
-            rv = merge(prop.readOnGadget(lhs.constData()), rv);
-        } else if (mt == QMetaType::QVariantList && std::strcmp(prop.name(), "subjectOf") == 0) {
-            rv = mergeSubjectOf(lv.toList(), rv.toList());
-        } else if (mt == QMetaType::QString) {
-            rv = StringUtil::betterString(lv.toString(), rv.toString()).toString();
-        }
-
-        if (!JsonLd::valueIsNull(rv)) {
-            prop.writeOnGadget(res.data(), rv);
+            if (!JsonLd::valueIsNull(rv)) {
+                prop.writeOnGadget(res.data(), rv);
+            }
         }
     }
 
