@@ -7,7 +7,7 @@ function parseBoardingPass(pdf, node, triggerNode) {
     var res = triggerNode.result[0];
     const page = pdf.pages[triggerNode.location];
     const timesText = page.textInRect(0.5, 0.5, 1, 1);
-    const times = timesText.match(/\n(\d\d:\d\d)[\s\S]*?\n(\d\d:\d\d)[\s\S]*?\n(\d\d:\d\d)[\s\S]*?\n(\d\d:\d\d)[\s\S]*?\d\d:\d\d\./);
+    const times = timesText.match(/\n(\d\d:\d\d)[\s\S]*?\n(\d\d:\d\d)[\s\S]*?\n(\d\d:\d\d)[\s\S]*?\n(\d\d:\d\d)/);
     res.reservationFor.boardingTime = JsonLd.toDateTime(times[2], "hh:mm", "en");
     res.reservationFor.departureTime = JsonLd.toDateTime(times[3], "hh:mm", "en");
     res.reservationFor.arrivalTime = JsonLd.toDateTime(times[4], "hh:mm", "en");
