@@ -11,7 +11,8 @@ function main(content) {
     var theDate = content.match(/Termin Datum: (.*)/)[1]
     var theTime = content.match(/Termin Uhrzeit: (.*) Uhr/)[1]
     var addr = content.match(/Adresse der Teststation: (.*), (.*), ([0-9]*) (.*)/)
-    var cancelUrl = content.match(/Für Absagen verwenden Sie bitte folgenden Link: (.*)/)[1]
+
+    var cancelUrlMatch = content.match(/Für Absagen verwenden Sie bitte folgenden Link: (.*)/)
 
     const address = JsonLd.newObject("PostalAddress")
     address.addressCountry = "DE"
@@ -21,13 +22,23 @@ function main(content) {
 
     res.reservationFor.name = name
 
-    res.potentialAction = JsonLd.newObject("CancelAction")
-    res.potentialAction.url = cancelUrl
+    // FIXME some cancel urls are not matched
+    if (cancelUrlMatch) {
+        res.potentialAction = JsonLd.newObject("CancelAction")
+        res.potentialAction.url = cancelUrlMatch[1]
+    }
 
     res.reservationFor.location.address = address
     res.reservationFor.location.name = addr[1]
 
-    res.reservationFor.startDate = JsonLd.toDateTime(theDate + " " + theTime, "dd.MM.yyyy hh:mm", "de")
+    // Both hh::mm and hh.mm are observed in the wild
+    var dateTime = JsonLd.toDateTime(theDate + " " + theTime, "dd.MM.yyyy hh:mm", "de")
+
+    if (isNaN(dateTime.getTime())) {
+        dateTime = JsonLd.toDateTime(theDate + " " + theTime, "dd.MM.yyyy hh.mm", "de")
+    }
+
+    res.reservationFor.startDate = dateTime
 
     return res
 }
